{#searchreplace_dlg.replace_title}

- {#searchreplace.search_desc}
- {#searchreplace_dlg.replace}

{#searchreplace_dlg.findwhat} |
{#searchreplace_dlg.direction} |  | {#searchreplace_dlg.up} |  | {#searchreplace_dlg.down}
| {#searchreplace_dlg.mcase}

{#searchreplace_dlg.findwhat} |
{#searchreplace_dlg.replacewith} |
{#searchreplace_dlg.direction} |  | {#searchreplace_dlg.up} |  | {#searchreplace_dlg.down}
| {#searchreplace_dlg.mcase}